<?php

/**
 * The public-facing functionality of the plugin.
 */
class Food_Recipes_Pack_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string $plugin_name The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string $version The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 *
	 * @param      string $plugin_name The name of the plugin.
	 * @param      string $version The version of this plugin.
	 */
	public function __construct( $plugin_name = '', $version = '' ) {

		$this->plugin_name = $plugin_name;
		$this->version     = $version;

		$this->load_dependencies();

	}

	/**
	 * Load the required dependencies for the admin side of the plugin.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 */
	private function load_dependencies() {
		/**
		 * This displays the rating functions
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-food-recipes-pack-rating.php';
	}

	/**
	 * Get and verify the reCaptcha v3 response
	 *
	 * @param $secret_key string
	 * @param $token string
	 *
	 * @return $response
	 */
	private function inspiry_verify_reCaptcha_response( $secret_key, $token ) {
		$response = wp_remote_get( "https://www.google.com/recaptcha/api/siteverify?secret=$secret_key&response=$token" );
		$return   = json_decode( $response );

		return $return;
	}

	public function inspiry_send_message() {
		if ( isset( $_POST['email'] ) ) :

			// verify nonce.
			$nonce = $_POST['nonce'];
			if ( ! wp_verify_nonce( $nonce, 'send_message_nonce' ) ) {
				echo wp_json_encode(
					array(
						'success' => false,
						'message' => esc_html__( 'Unverified Nonce!', 'food-recipes-pack' ),
					)
				);
				die;
			}

			// Testing reCaptcha
			$reCaptcha_secret_key = get_option( 'inspiry_google_reCaptcha_secret_key' );
			if ( ! empty( $reCaptcha_secret_key ) ) {
				$reCaptcha_response = false;
				if ( isset( $_POST['g-recaptcha-response'] ) ) {
					$reCaptcha_response = $this->inspiry_verify_reCaptcha_response( $reCaptcha_secret_key, $_POST['g-recaptcha-response'] );
				}

				if ( false === $reCaptcha_response->success || $reCaptcha_response->score < 0.5 ) {
					echo wp_json_encode(
						array(
							'success' => false,
							'message' => esc_html__( 'Captcha Failed. Reload the page and try again.', 'food-recipes-pack' ),
						)
					);
					die;
				}
			}

			/* Sanitize and Validate Target email address */
			$address = sanitize_email( get_option( 'theme_contact_address' ) );
			$address = is_email( $address );
			if ( ! $address ) {
				echo wp_json_encode(
					array(
						'success' => false,
						'message' => esc_html__( 'Target Email address is not properly configured!', 'food-recipes-pack' ),
					)
				);
				die;
			}


			$name    = sanitize_text_field( $_POST['name'] );
			$message = stripslashes( $_POST['message'] );
			$email   = sanitize_email( $_POST['email'] );
			$email   = is_email( $email );

			if ( ! $email ) {
				echo wp_json_encode(
					array(
						'success' => false,
						'message' => esc_html__( 'Provided Email address is invalid!', 'food-recipes-pack' ),
					)
				);
				die;
			}

			$e_subject = esc_html__( 'New message sent by', 'food-recipes-pack' ) . ' ' . $name . ' ' . esc_html__( 'using contact form at', 'food-recipes-pack' ) . ' ' . get_bloginfo( 'name' );

			$e_body = esc_html__( 'You have Received a message from: ', 'food-recipes-pack' ) . $name . '<br/>' . esc_html__( 'Their additional message is as follows.', 'food-recipes-pack' ) . '<br/>';

			$e_content = wpautop( $message ) . '<br/>';

			$e_reply = esc_html__( 'You can contact', 'food-recipes-pack' ) . ' ' . $name . ' ' . esc_html__( 'via email,', 'food-recipes-pack' ) . ' ' . $email;

			$full_message = $e_body . $e_content . $e_reply;
			$header       = 'Content-type: text/html; charset=utf-8' . "\r\n";
			$header       = apply_filters( 'inspiry_contact_mail_header', $header );
			$header       .= 'From: ' . $name . '<' . $email . "> \r\n";

			if ( wp_mail( $address, $e_subject, $full_message, $header ) ) {
				echo wp_json_encode(
					array(
						'success' => true,
						'message' => esc_html__( 'Message Sent Successfully!', 'food-recipes-pack' ),
					)
				);
			} else {
				echo wp_json_encode(
					array(
						'success' => false,
						'message' => esc_html__( 'Server Error: WordPress mail function failed!', 'food-recipes-pack' ),
					)
				);
			}

		else :

			echo wp_json_encode(
				array(
					'success' => false,
					'message' => esc_html__( 'Invalid Request !', 'food-recipes-pack' ),
				)
			);

		endif;

		die;

	}

	public static function render_contact_form() {
		?>
        <h3 id="contact-template-form-heading"><?php echo esc_attr( get_option( 'contact_form_heading' ) ); ?></h3>

        <span class="w-pet-border"></span>
        <form id="contact-form" action="<?php echo esc_url( admin_url( 'admin-ajax.php' ) ); ?>" method="post">
            <p><input type="text" name="name" class="required" id="cname"
                      data-msg-required="<?php esc_html_e( '* Please enter your name.', 'food-recipes-pack' ); ?>"
                      data-rule-required="true" placeholder="<?php esc_html_e( 'Name here', 'food-recipes-pack' ); ?>"/>
            </p>
            <p>
                <input type="text" id="cemail" name="email" class="email" data-rule-required="true"
                       data-rule-email="true"
                       data-msg-required="<?php esc_html_e( '* Please enter your email address', 'food-recipes-pack' ); ?>"
                       data-msg-email="<?php esc_html_e( '* Please enter a valid email address', 'food-recipes-pack' ); ?>"
                       aria-required="true" placeholder="<?php esc_html_e( 'Email here', 'food-recipes-pack' ); ?>">
            </p>
            <p><textarea name="message" id="cmessage" class="required"
                         title="<?php esc_html_e( '* You must enter message.', 'food-recipes-pack' ); ?>" cols="30"
                         rows="6" placeholder="<?php esc_html_e( 'Message', 'food-recipes-pack' ); ?>"></textarea></p>
            <p>
                <input type="hidden" name="action" value="send_message"/>
                <input type="hidden" name="nonce"
                       value="<?php echo esc_attr( wp_create_nonce( 'send_message_nonce' ) ); ?>"/>
                <input class="readmore" type="submit" name="contact-submit" id="contact-submit"
                       value="<?php esc_html_e( 'Send Now', 'food-recipes-pack' ); ?>"/>
                <img src="<?php echo get_template_directory_uri(); ?>/images/loading.gif" id="contact-loader"
                     alt="Loader"/>
            </p>
			<?php if ( ! empty( get_option( 'inspiry_google_recaptcha_site_key' ) ) ) : ?>
                <input id="contact-recaptcha-response" type="hidden" name="g-recaptcha-response" value=""/>
			<?php endif; ?>
            <p id="message-sent"></p>
            <div id="search-error-container"></div>
        </form>
		<?php
	}

	public static function render_user_profile_form( $current_user, $referer ) {
		?>
        <form method="post" id="adduser" action="<?php the_permalink(); ?>" enctype="multipart/form-data">
            <p class="form-photo">
                <label for="photo"><?php esc_html_e( 'Update Photo', 'food-recipes-pack' ); ?></label>
	            <?php
				$avatar = get_the_author_meta( 'photo', $current_user->ID );
				if( !empty( $avatar ) ){
					?>
					<span class="form-avatar clearfix">
					<img src="<?php echo esc_url( get_the_author_meta( 'photo', $current_user->ID ) ); ?>"
					     alt="<?php echo esc_attr( get_the_author_meta( 'first_name', $current_user->ID ) ) ?>"/>
					</span>
					<?php
				}
	            ?>
                <span class="note clearfix">
					<input class="text-input" name="photo" type="file" id="photo"
                           value="<?php the_author_meta( 'photo', $current_user->ID ); ?>"/>
					<small><?php esc_html_e( 'Image should have 250px width and 215px height. Large images will be cropped automatically.', 'food-recipes-pack' ); ?></small>
				</span>

            </p><!-- .form-photo -->
            <p class="form-textarea clearfix">
                <label for="description"><?php esc_html_e( 'Biographical Info', 'food-recipes-pack' ); ?></label>
                <textarea name="description" id="description" rows="5"
                          cols="50"><?php the_author_meta( 'description', $current_user->ID ); ?></textarea>
            </p><!-- .form-textarea -->
            <p class="form-username clearfix">
                <label for="first-name"><?php esc_html_e( 'First Name', 'food-recipes-pack' ); ?></label>
                <input class="text-input" name="first-name" type="text" id="first-name"
                       value="<?php the_author_meta( 'first_name', $current_user->ID ); ?>"/>
            </p><!-- .form-username -->

            <p class="form-username clearfix">
                <label for="last-name"><?php esc_html_e( 'Last Name', 'food-recipes-pack' ); ?></label>
                <input class="text-input" name="last-name" type="text" id="last-name"
                       value="<?php the_author_meta( 'last_name', $current_user->ID ); ?>"/>
            </p><!-- .form-username -->

            <!-- .form-display_name -->
            <p class="form-display_name clearfix">
                <label for="display_name"><?php esc_html_e( 'Display publicly as', 'food-recipes-pack' ); ?></label>

                <select name="display_name" id="display_name"><br/>
					<?php
					$public_display                     = array();
					$public_display['display_nickname'] = $current_user->nickname;
					$public_display['display_username'] = $current_user->user_login;

					if ( ! empty( $current_user->first_name ) ) {
						$public_display['display_firstname'] = $current_user->first_name;
					}

					if ( ! empty( $current_user->last_name ) ) {
						$public_display['display_lastname'] = $current_user->last_name;
					}

					if ( ! empty( $current_user->first_name ) && ! empty( $current_user->last_name ) ) {
						$public_display['display_firstlast'] = $current_user->first_name . ' ' . $current_user->last_name;
						$public_display['display_lastfirst'] = $current_user->last_name . ' ' . $current_user->first_name;
					}
					// Only add this if it isn't duplicated elsewhere.
					if ( ! in_array( $current_user->display_name, $public_display, true ) ) {
						$public_display = array( 'display_displayname' => $current_user->display_name ) + $public_display;
					}

					$public_display = array_map( 'trim', $public_display );
					$public_display = array_unique( $public_display );

					foreach ( $public_display as $id => $item ) {
						?>
                        <option <?php selected( $current_user->display_name, $item ); ?>><?php echo esc_html( $item ); ?></option>
						<?php
					}
					?>
                </select>
            </p><!-- .form-display_name -->

            <p class="form-email clearfix">
                <label for="email"><?php esc_html_e( 'E-mail *', 'food-recipes-pack' ); ?></label>
                <input class="text-input" name="email" type="text" id="email"
                       value="<?php the_author_meta( 'user_email', $current_user->ID ); ?>"/>
            </p><!-- .form-email -->

            <p class="form-url clearfix">
                <label for="url"><?php esc_html_e( 'Website', 'food-recipes-pack' ); ?></label>
                <input class="text-input" name="url" type="text" id="url"
                       value="<?php the_author_meta( 'user_url', $current_user->ID ); ?>"/>
            </p><!-- .form-url -->

            <p class="form-designation clearfix">
                <label for="user_designation"><?php esc_html_e( 'User Designation', 'food-recipes-pack' ); ?></label>
                <input class="text-input" name="user_designation" type="text" id="user_designation"
                       value="<?php the_author_meta( 'user_designation', $current_user->ID ); ?>"/>
            </p><!-- .form-designation -->

            <p class="form-password clearfix">
                <label for="pass1"><?php esc_html_e( 'Password *', 'food-recipes-pack' ); ?> </label>
                <input class="text-input" name="pass1" type="password" id="pass1"/>
            </p><!-- .form-password -->

            <p class="form-password clearfix">
                <label for="pass2"><?php esc_html_e( 'Repeat Password *', 'food-recipes-pack' ); ?></label>
                <input class="text-input" name="pass2" type="password" id="pass2"/>
            </p><!-- .form-password -->

            <p class="form-twitter clearfix">
                <label for="twitter"><?php esc_html_e( 'Twitter URL', 'food-recipes-pack' ); ?></label>
                <input class="text-input" name="twitter" type="text" id="twitter"
                       value="<?php the_author_meta( 'twitter', $current_user->ID ); ?>"/>
            </p><!-- .form-twitter -->

            <p class="form-facebook clearfix">
                <label for="facebook"><?php esc_html_e( 'Facebook URL', 'food-recipes-pack' ); ?></label>
                <input class="text-input" name="facebook" type="text" id="facebook"
                       value="<?php the_author_meta( 'facebook', $current_user->ID ); ?>"/>
            </p><!-- .form-facebook -->

            <p class="form-linkedin clearfix">
                <label for="linkedin"><?php esc_html_e( 'Linkedin URL', 'food-recipes-pack' ); ?></label>
                <input class="text-input" name="linkedin" type="text" id="linkedin"
                       value="<?php the_author_meta( 'linkedin', $current_user->ID ); ?>"/>
            </p><!-- .form-linkedin -->

            <p class="form-youtube clearfix">
                <label for="youtube"><?php esc_html_e( 'Youtube URL', 'food-recipes-pack' ); ?></label>
                <input class="text-input" name="youtube" type="text" id="youtube"
                       value="<?php the_author_meta( 'youtube', $current_user->ID ); ?>"/>
            </p><!-- .form-youtube -->

            <p class="form-submit">
				<?php echo esc_html( $referer ); ?>
                <input name="updateuser" type="submit" id="updateuser" class="submit button readmore"
                       value="<?php esc_html_e( 'Update', 'food-recipes-pack' ); ?>"/>
				<?php wp_nonce_field( 'update-user_' . $current_user->ID ); ?>
                <input name="action" type="hidden" id="action" value="update-user"/>
            </p><!-- .form-submit -->
        </form><!-- #adduser -->
		<?php
	}

	public static function render_submit_recipe( $show_message ) {
		if ( ! $show_message ) {
			?>
            <a class="logout_link" href="<?php echo wp_logout_url( get_permalink() . '#login-signup-forgot' ); ?>"
               title="<?php esc_html_e( 'Logout', 'food-recipes-pack' ); ?>"><?php esc_html_e( 'Logout', 'food-recipes-pack' ); ?></a>
            <form id="recipe-form" name="recipe-form" action="#" method="post" enctype="multipart/form-data">

                <!-- recipe title -->
                <fieldset name="recipe-title" class="recipe-title">
                    <label for="inspiry_recipe_title"><?php esc_html_e( 'Recipe Title', 'food-recipes-pack' ); ?></label>
                    <input type="text" id="inspiry_recipe_title" value="" tabindex="15" name="inspiry_recipe_title"
                           data-msg-required="<?php esc_html_e( 'Please enter recipe title', 'food-recipes-pack' ); ?>"
                           data-rule-required="true" aria-required="true"/>
                </fieldset>

                <!-- recipe excerpt -->
                <fieldset class="content">
                    <label for="short-description"><?php esc_html_e( 'Short Description', 'food-recipes-pack' ); ?></label>
                    <textarea id="short-description" tabindex="16" name="short-description"
                              data-msg-required="<?php esc_html_e( 'Please enter some short description', 'food-recipes-pack' ); ?>"
                              data-rule-required="true" aria-required="true" cols="80" rows="3"
                              class="tinymce-enabled"></textarea>
                </fieldset>

                <!-- recipe content -->
                <fieldset class="content">
                    <label for="description"><?php esc_html_e( 'Recipe Content', 'food-recipes-pack' ); ?></label>
					<?php

					$settings = array(
						'tabindex'     => 17,
						'editor_class' => ''
					);

					wp_editor( '', 'description', $settings );
					?>
                </fieldset>
                <!-- recipe featured image -->
                <fieldset class="recipe-image">
                    <label><?php esc_html_e( 'Recipe Images', 'food-recipes-pack' ); ?></label>
                    <span class="note"><strong>* <?php esc_html_e( 'Image size must be more than 575px in width and 262px in height.', 'food-recipes-pack' ); ?></strong></span>
                    <span class="note"><strong>* <?php esc_html_e( 'You can mark an image as featured by clicking the star icon, Otherwise first image will be considered featured image.', 'food-recipes-pack' ); ?></strong></span>

                    <div id="gallery-thumbs-container" class="clearfix"></div>
                <div id="drag-and-drop">
                    <div class="drag-drop-msg text-center">&nbsp;
                        <?php esc_html_e( 'Drag and drop images here', 'food-recipes-pack' ); ?>
                        <br/>
                        <span class="drag-or"><?php esc_html_e( 'OR', 'food-recipes-pack' ); ?></span>
                        <br/>
                        <a id="select-images" class="drag-btn readmore" href="javascript:;">
                            <?php esc_html_e( 'Select Images', 'food-recipes-pack' ); ?>
                        </a>
                    </div>
                </div>
                <div id="plupload-container"></div>
                <div id="errors-log"></div>
                </fieldset>

                <fieldset class="incobjs ingre-wrap">
                    <label><?php esc_html_e( 'Ingredients', 'food-recipes-pack' ); ?></label>
                    <input type="text" name="ingredient[]" id="ingredient" size="50">
                    <span class="more-ingre">+</span>
                    <span class="note"><?php esc_html_e( 'Use + button on the right to add new ingredient.', 'food-recipes-pack' ); ?></span>
                </fieldset>
                <fieldset class="incobjs steps-wrap">
                    <label><?php esc_html_e( 'Steps', 'food-recipes-pack' ); ?></label>
                    <textarea name="recipe_step[]" id="recipe_step" cols="60" rows="3"></textarea>
                    <span class="more-ingre">+</span>
                    <span class="note"><?php esc_html_e( 'Use + button on the right to add new step.', 'food-recipes-pack' ); ?></span>
                </fieldset>
                <fieldset>
                    <label><?php esc_html_e( 'Video Based Recipe', 'food-recipes-pack' ); ?></label>
                    <select id="video-based" name="video_based_recipe">
                        <option value="on"><?php esc_html_e( 'Yes', 'food-recipes-pack' ); ?></option>
                        <option value="off"
                                selected><?php esc_html_e( 'No', 'food-recipes-pack' ); ?></option>
                    </select>
                    <span class="note"><?php esc_html_e( 'A Video Based recipe does not display attached images and only display a video at top.', 'food-recipes-pack' ); ?></span>
                </fieldset>
                <fieldset>
                    <label for="video-embed-code"><?php esc_html_e( 'Video Embed Code', 'food-recipes-pack' ); ?></label>
                    <textarea name="video_embed_code" id="video-embed-code" cols="60" rows="3"></textarea><br>
                    <span class="note">* <?php esc_html_e( 'Provide the video embed code and Modify the width attribute to 575px and height attribute to 262px.', 'food-recipes-pack' ); ?></span>
                </fieldset>
                <!-- recipe detail -->
                <fieldset name="recipe-detail" class="recipe-detail">

                    <div>
                        <label for="yield"><?php esc_html_e( 'Yield', 'food-recipes-pack' ); ?></label>
                        <input type="text" id="yield" value="" tabindex="19" name="yield"/>

                        <label for="servings"><?php esc_html_e( 'Servings', 'food-recipes-pack' ); ?></label>
                        <input type="text" id="servings" value="" tabindex="20" name="servings"/>
                    </div>

                    <div>
                        <span class="note">* <?php esc_html_e( 'Specify the time in minutes and value greater than 60 will be automatically displayed in hours.', 'food-recipes-pack' ); ?></span>
                        <label for="prep-time"><?php esc_html_e( 'Prep Time', 'food-recipes-pack' ); ?></label>
                        <input type="text" id="prep-time" value="" tabindex="21" name="prep-time"/>


                        <label for="cook-time"><?php esc_html_e( 'Cook Time', 'food-recipes-pack' ); ?></label>
                        <input type="text" id="cook-time" value="" tabindex="22" name="cook-time"/>

                        <label for="ready-in"><?php esc_html_e( 'Ready In', 'food-recipes-pack' ); ?></label>
                        <input type="text" id="ready-in" value="" tabindex="23" name="ready-in"/>
                    </div>

                </fieldset>

                <!-- recipe categories -->
                <fieldset name="recipe-categories" class="recipe-categories clearfix">

                    <div class="clearfix">
                        <label for="tags"
                               class="for-tags"><?php esc_html_e( 'Tags', 'food-recipes-pack' ); ?></label>
                        <input type="text" id="tags" value="" tabindex="24" name="tags"/> <br>
                        <span class="note">* <?php esc_html_e( 'Tags keywords should all be in lowercase and separated by commas', 'food-recipes-pack' ); ?></span>
                    </div>

                    <div class="clearfix">
                        <label for="recipe-type"><?php esc_html_e( 'Recipe Type', 'food-recipes-pack' ); ?></label>
						<?php wp_dropdown_categories( 'tab_index=25&taxonomy=recipe_type&name=recipe-type&orderby=name&order=asc&show_option_none=' . esc_html__( 'None', 'food-recipes-pack' ) . '&hide_empty=0' ); ?>
                    </div>

                    <div class="clearfix">
                        <label for="cuisine"><?php esc_html_e( 'Cuisine', 'food-recipes-pack' ); ?></label>
						<?php wp_dropdown_categories( 'tab_index=26&taxonomy=cuisine&name=cuisine&orderby=name&order=asc&show_option_none=' . esc_html__( 'None', 'food-recipes-pack' ) . '&hide_empty=0' ); ?>
                    </div>

                    <div class="clearfix">
                        <label for="course"><?php esc_html_e( 'Course', 'food-recipes-pack' ); ?></label>
						<?php wp_dropdown_categories( 'tab_index=27&taxonomy=course&name=course&orderby=name&order=asc&show_option_none=' . esc_html__( 'None', 'food-recipes-pack' ) . '&hide_empty=0' ); ?>
                    </div>

                    <div class="clearfix">
                        <label for="skill-level"><?php esc_html_e( 'Skill Level', 'food-recipes-pack' ); ?></label>
						<?php wp_dropdown_categories( 'tab_index=28&taxonomy=skill_level&name=skill-level&orderby=name&order=asc&show_option_none=' . esc_html__( 'None', 'food-recipes-pack' ) . '&hide_empty=0' ); ?>
                    </div>

                </fieldset>

                <fieldset class="submit">
                    <input type="submit"
                           value="<?php esc_html_e( 'Submit Recipe', 'food-recipes-pack' ); ?>"
                           tabindex="40" id="submit" name="submit" class="readmore"/>
                </fieldset>

                <input type="hidden" name="action" value="submit-recipe"/>
				<?php wp_nonce_field( 'submit-recipe' ); ?>

            </form>
			<?php
		} else { ?>
            <div class="recipe-message">
                <h3><?php esc_html_e( 'Thanks for Submit!', 'food-recipes-pack' ); ?></h3>
                <h4><?php echo esc_html__( 'We will publish your Recipe after Review.', 'food-recipes-pack' ); ?></h4>
            </div>
			<?php
		}
	}

	/**
	 * Login Form for recipe submit template
	 *
	 * @since   1.0.2
	 */
	public static function render_submit_login_forms() {
		?>
		<div class="tabed" id="login-signup-forgot">

			<ul class="tabs">
				<li class="current"><?php esc_html_e( 'Login', 'food-recipes-pack' ); ?><span></span></li>
				<?php if ( get_option( 'users_can_register' ) ) : ?>
					<li><?php esc_html_e( 'Sign Up', 'food-recipes-pack' ); ?><span></span></li>
				<?php endif; ?>
				<li><?php esc_html_e( 'Forgot Password', 'food-recipes-pack' ); ?><span></span></li>
			</ul>

			<div class="block current">
				<form id="login" action="login" method="post">

					<p>
						<label for="username"><?php esc_html_e( 'Username', 'food-recipes-pack' ); ?></label>
						<input id="username" type="text" name="username">
					</p>
					<p>
						<label for="password"><?php esc_html_e( 'Password', 'food-recipes-pack' ); ?></label>
						<input id="password" type="password" name="password">
					</p>
					<p>
						<input type="checkbox" value="forever" name="rememberme" id="remember" class="checkbox">
						<label class="checkbox-label" for="remember"><?php esc_html_e( 'Remember me', 'food-recipes-pack' ); ?></label>
						<br>
						<input id="login-submit" class="submit_button readmore" type="submit" value="<?php esc_html_e( 'Login!', 'food-recipes-pack' ); ?>"
						       name="submit">

						<img id="login-loader"
						     src="<?php echo get_template_directory_uri() . '/images/loading.gif' ?>"
						     alt="Loader"/>
						<?php wp_nonce_field( 'ajax-login-nonce', 'security' ); ?>
					</p>
					<p class="status"></p>
				</form>
			</div>

			<?php if ( get_option( 'users_can_register' ) ) : ?>
				<div class="block">
					<form action="<?php echo site_url( 'wp-login.php?action=register', 'login_post' ) ?>"
					      id="signup-form" method="post">
						<p>
							<label for="userName"><?php esc_html_e( 'Username', 'food-recipes-pack' ); ?></label>
							<input type="text" id="userName" name="user_login"/>
						</p>
						<p>
							<label for="user_email"><?php esc_html_e( 'Email', 'food-recipes-pack' ); ?></label>
							<input type="text" id="user_email" name="user_email"/>
						</p>
						<p>
							<input type="submit" class="readmore" name="user-submit" value="<?php esc_html_e( 'Sign Up!', 'food-recipes-pack' ); ?>"/>
							<input type="hidden" name="redirect_to" value="<?php the_permalink(); ?>"/>
							<input type="hidden" name="user-cookie" value="1"/>
						</p>
					</form>
				</div>
			<?php endif; ?>

			<div class="block">
				<form action="<?php echo site_url( 'wp-login.php?action=lostpassword', 'login_post' ) ?>"
				      id="forgot-form" method="post">
					<p>
						<label for="user_login"
						       class="forgot-email"><?php esc_html_e( 'Username or Email', 'food-recipes-pack' ); ?></label>
						<input type="text" name="user_login" value="" id="user_login"/>
					</p>
					<p>
						<input type="submit" class="readmore" name="user-submit"
						       value="<?php esc_html_e( 'Reset my password', 'food-recipes-pack' ); ?>"/>
						<input type="hidden" name="redirect_to" value="<?php the_permalink(); ?>"/>
						<input type="hidden" name="user-cookie" value="1"/>
					</p>
				</form>
			</div>

		</div><!-- end of tabed div -->
		<?php
	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		wp_register_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . '../js/custom.js', array( 'jquery' ), $this->version, true );

		if ( is_page_template( 'template-recipe-submit.php' ) || is_page_template( 'template-contact.php' ) || is_singular( 'recipe' ) ) {

			wp_enqueue_script( $this->plugin_name . '-jquery.form', plugin_dir_url( __FILE__ ) . '../js/jquery.form.min.js', array( 'jquery' ), '3.51.0', true );
			wp_enqueue_script( $this->plugin_name . '-jquery.form.validate', plugin_dir_url( __FILE__ ) . '../js/jquery.validate.min.js', array( 'jquery' ), '1.19.0', true );
			wp_register_script( $this->plugin_name . 'login-script', plugin_dir_url( __FILE__ ) . '../js/ajax-login-script.js', array( 'jquery' ), $this->version, true );

			wp_localize_script(
				$this->plugin_name,
				'contact_recaptcha',
				array(
					'site_key' => get_option( 'inspiry_google_recaptcha_site_key' ),
				)
			);
		}

		if ( is_page_template( 'template-recipe-submit.php' ) ) {
			wp_enqueue_style( $this->plugin_name . 'jquery_ui_css', plugin_dir_url( __FILE__ ) . '../css/jquery-ui.min.css' );
			wp_enqueue_style( $this->plugin_name . 'plupload_css', plugin_dir_url( __FILE__ ) . '../js/jquery.ui.plupload/css/jquery.ui.plupload.css' );
			wp_enqueue_script( $this->plugin_name . 'plupload-full', plugin_dir_url( __FILE__ ) . '../js/plupload.full.min.js', array(
				'jquery',
			), '1.3.5', true );
			wp_enqueue_script( $this->plugin_name . 'plupload-min', plugin_dir_url( __FILE__ ) . '../js/jquery.ui.plupload/jquery.ui.plupload.min.js', array(
				'jquery',
				'jquery-ui-core',
				'jquery-ui-widget',
				'jquery-ui-button',
				'jquery-ui-progressbar',
			), '1.2.1', true );
		}

		if ( is_page_template( 'template-contact.php' ) && ! empty( get_option( 'inspiry_google_recaptcha_site_key' ) ) ) {
			wp_enqueue_script(
				$this->plugin_name . 'google-recaptcha',
				'https://www.google.com/recaptcha/api.js?render=' . get_option( 'inspiry_google_recaptcha_site_key' ),
				array(),
				'1.0',
				true
			);
		}

		if ( ! is_user_logged_in() ) {
			wp_register_script( $this->plugin_name . 'login-script', plugin_dir_url( __FILE__ ) . '../js/ajax-login-script.js', array( 'jquery' ), $this->version, true );
			wp_localize_script(
				$this->plugin_name . 'login-script',
				'ajax_login_object',
				array(
					'ajax_url'        => admin_url( 'admin-ajax.php' ),
					'redirect_url'    => get_the_permalink(),
					'loading_message' => '',
				)
			);
			wp_enqueue_script( $this->plugin_name . 'login-script' );
		}
		wp_enqueue_script( $this->plugin_name );
	}

}
