<?php

/**
 * The core plugin class.
 *
 */
class Food_Recipes_Pack {

	/**
	 * @var      Food_Recipes_Pack_Loader $loader Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * @var      string $plugin_name The string used to uniquely identify this plugin.
	 */
	protected $plugin_name;

	/**
	 * @var      string $version The current version of the plugin.
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 */
	public function __construct() {

		if ( defined( 'FOOD_RECIPES_PACK_VERSION' ) ) {
			$this->version = FOOD_RECIPES_PACK_VERSION;
		} else {
			$this->version = '1.0.3';
		}

		$this->plugin_name = 'food-recipes-pack';

		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_public_hooks();

	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 */
	private function load_dependencies() {

		/**
		 * Metabox required plugin included in foodrecipes pack with extensions
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-food-recipes-meta-boxes.php';

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-food-recipes-pack-loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-food-recipes-pack-i18n.php';

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-food-recipes-pack-admin.php';

		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-food-recipes-pack-public.php';

		$this->loader = new Food_Recipes_Pack_Loader();

	}

	/**
	 * Define the locale for this plugin for internationalization.
	 */
	private function set_locale() {
		$plugin_i18n = new Food_Recipes_Pack_i18n();
		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );
	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 */
	private function define_admin_hooks() {

		$plugin_admin = new Food_Recipes_Pack_Admin( $this->get_plugin_name(), $this->get_version() );
		$this->loader->add_action( 'widgets_init', $plugin_admin, 'register_theme_widgets' );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_styles' );

		// User columns
		$this->loader->add_filter( 'manage_users_columns', $plugin_admin, 'inspiry_add_user_post_type_columns', 12 );
		$this->loader->add_filter( 'manage_users_custom_column', $plugin_admin, 'inspiry_manage_post_type_columns', 10, 3 );
		$this->loader->add_filter( 'manage_users_sortable_columns', $plugin_admin, 'make_add_post_type_sortable' );

		$plugin_customize = new Food_Recipes_Pack_WP_Customize_Manager();
		$this->loader->add_action( 'customize_register', $plugin_customize, 'inspiry_admin_customizer', 11 );
		$this->loader->add_action( 'customize_register', $plugin_customize, 'inspiry_recipe_single_customizer', 11 );
		$this->loader->add_action( 'customize_register', $plugin_customize, 'inspiry_recipe_slugs_customizer', 11 );
		$this->loader->add_action( 'customize_register', $plugin_customize, 'inspiry_recipe_submit_customizer', 11 );
		$this->loader->add_action( 'customize_register', $plugin_customize, 'inspiry_recipes_listing_customizer', 11 );
		$this->loader->add_action( 'customize_register', $plugin_customize, 'inspiry_advance_search_customizer', 11 );
		$this->loader->add_action( 'customize_register', $plugin_customize, 'inspiry_google_keys_customizer', 11 );
		$this->loader->add_action( 'customize_save_after', $plugin_customize, 'inspiry_admin_customizer_default', 12 );

		$plugin_post_type = new Food_Recipes_Pack_Post_Type();
		$this->loader->add_filter( 'the_content_feed', $plugin_post_type, 'rss_post_thumbnail' );
		$this->loader->add_action( 'init', $plugin_post_type, 'create_recipe' );
		$this->loader->add_action( 'init', $plugin_post_type, 'build_taxonomies', 0 );
		$this->loader->add_filter( 'manage_edit-recipe_columns', $plugin_post_type, 'recipe_edit_columns' );
		$this->loader->add_action( 'manage_posts_custom_column', $plugin_post_type, 'recipe_custom_columns' );
		$this->loader->add_filter( 'request', $plugin_post_type, 'my_recipes_feed' );
		$this->loader->add_filter( 'single_template', $plugin_post_type, 'alter_recipe_singular' );
		$this->loader->add_filter( 'the_excerpt_rss', $plugin_post_type, 'rss_post_thumbnail_excerpt' );

		$plugin_user_fields = new Food_Recipes_Pack_User_Fields();
		$this->loader->add_action( 'show_user_profile', $plugin_user_fields, 'inspiry_additional_user_fields' );
		$this->loader->add_action( 'edit_user_profile', $plugin_user_fields, 'inspiry_additional_user_fields' );
		$this->loader->add_action( 'personal_options_update', $plugin_user_fields, 'inspiry_save_additional_user_meta' );
		$this->loader->add_action( 'edit_user_profile_update', $plugin_user_fields, 'inspiry_save_additional_user_meta' );

		$plugin_email = new Food_Recipes_Pack_Mail();
		$this->loader->add_filter( 'wp_mail_from_name', $plugin_email, 'inspiry_mail_from_name' );
		$this->loader->add_action( 'wp_ajax_nopriv_send_message', $plugin_email, 'send_message' );
		$this->loader->add_action( 'wp_ajax_send_message', $plugin_email, 'send_message' );


		$plugin_typography = new Food_Recipes_Pack_Typography();
		$plugin_elements   = new Food_Recipes_Pack_Elements();
		$plugin_columns    = new Food_Recipes_Pack_Columns();
	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_public_hooks() {

		$plugin_public = new Food_Recipes_Pack_Public( $this->get_plugin_name(), $this->get_version() );
		$this->loader->add_action( 'wp_ajax_nopriv_send_message', $plugin_public, 'inspiry_send_message' );
		$this->loader->add_action( 'wp_ajax_send_message', $plugin_public, 'inspiry_send_message' );
		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_scripts' );


		$plugin_rating = new Food_Recipes_Pack_Pack_Rating();
		$this->loader->add_action( 'wp_ajax_nopriv_inspiry_rate_this', $plugin_rating, 'inspiry_rate_this' );
		$this->loader->add_action( 'wp_ajax_inspiry_rate_this', $plugin_rating, 'inspiry_rate_this' );
	}

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run() {
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_plugin_name() {
		return $this->plugin_name;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    Food_Recipes_Pack_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader() {
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}

}
